@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "settingsfileexporterwidget.h"
@@ -20,14 +20,14 @@
 #include <QFormLayout>
 #include <QCheckBox>
 #include <QSpinBox>
+#include <QPushButton>
+#include <qplatformdefs.h>
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KSharedConfig>
 #include <KConfigGroup>
 #include <KComboBox>
 #include <KLineEdit>
-#include <KPushButton>
-#include <KFileDialog>
 #include <KUrlRequester>
 
 #include "guihelper.h"
@@ -48,15 +48,19 @@ private:
     KSharedConfigPtr config;
 
 public:
+#ifdef QT_LSTAT
     QCheckBox *checkboxUseAutomaticLyXPipeDetection;
+#endif // QT_LSTAT
     KComboBox *comboBoxBackupScope;
     QSpinBox *spinboxNumberOfBackups;
 
     KUrlRequester *lineeditLyXPipePath;
-    QString lastUserInput;
+#ifdef QT_LSTAT
+    QString lastUserInputLyXPipePath;
+#endif // QT_LSTAT
 
     SettingsFileExporterWidgetPrivate(SettingsFileExporterWidget *parent)
-            : p(parent), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))) {
+            : p(parent), config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc"))) {
         setupGUI();
     }
 
@@ -71,9 +75,13 @@ public:
         spinboxNumberOfBackups->setValue(qMax(0, qMin(spinboxNumberOfBackups->maximum(), configGroup.readEntry(Preferences::keyNumberOfBackups, Preferences::defaultNumberOfBackups))));
 
         KConfigGroup configGroupLyX(config, LyX::configGroupName);
+#ifndef QT_LSTAT
+        lineeditLyXPipePath->setText(configGroupLyX.readEntry(LyX::keyLyXPipePath, LyX::defaultLyXPipePath));
+#else // QT_LSTAT
         checkboxUseAutomaticLyXPipeDetection->setChecked(configGroupLyX.readEntry(LyX::keyUseAutomaticLyXPipeDetection, LyX::defaultUseAutomaticLyXPipeDetection));
-        lastUserInput = configGroupLyX.readEntry(LyX::keyLyXPipePath, LyX::defaultLyXPipePath);
+        lastUserInputLyXPipePath = configGroupLyX.readEntry(LyX::keyLyXPipePath, LyX::defaultLyXPipePath);
         p->automaticLyXDetectionToggled(checkboxUseAutomaticLyXPipeDetection->isChecked());
+#endif // QT_LSTAT
     }
 
     void saveState() {
@@ -85,8 +93,12 @@ public:
         configGroup.writeEntry(Preferences::keyNumberOfBackups, spinboxNumberOfBackups->value());
 
         KConfigGroup configGroupLyX(config, LyX::configGroupName);
+#ifndef QT_LSTAT
+        configGroupLyX.writeEntry(LyX::keyLyXPipePath, lineeditLyXPipePath->text());
+#else // QT_LSTAT
         configGroupLyX.writeEntry(LyX::keyUseAutomaticLyXPipeDetection, checkboxUseAutomaticLyXPipeDetection->isChecked());
-        configGroupLyX.writeEntry(LyX::keyLyXPipePath, checkboxUseAutomaticLyXPipeDetection->isChecked() ? lastUserInput : lineeditLyXPipePath->text());
+        configGroupLyX.writeEntry(LyX::keyLyXPipePath, checkboxUseAutomaticLyXPipeDetection->isChecked() ? lastUserInputLyXPipePath : lineeditLyXPipePath->text());
+#endif // QT_LSTAT
 
         config->sync();
     }
@@ -99,9 +111,13 @@ public:
         comboBoxBackupScope->setCurrentIndex(index);
         spinboxNumberOfBackups->setValue(qMax(0, qMin(spinboxNumberOfBackups->maximum(), Preferences::defaultNumberOfBackups)));
 
+#ifndef QT_LSTAT
+        const QString pipe = LyX::defaultLyXPipePath;
+#else // QT_LSTAT
         checkboxUseAutomaticLyXPipeDetection->setChecked(LyX::defaultUseAutomaticLyXPipeDetection);
         QString pipe = LyX::guessLyXPipeLocation();
         if (pipe.isEmpty()) pipe = LyX::defaultLyXPipePath;
+#endif // QT_LSTAT
         lineeditLyXPipePath->setText(pipe);
     }
 
@@ -109,27 +125,29 @@ public:
         QFormLayout *layout = new QFormLayout(p);
 
         comboBoxCopyReferenceCmd = new KComboBox(false, p);
-        comboBoxCopyReferenceCmd->setObjectName("comboBoxCopyReferenceCmd");
+        comboBoxCopyReferenceCmd->setObjectName(QStringLiteral("comboBoxCopyReferenceCmd"));
         layout->addRow(i18n("Command for 'Copy Reference':"), comboBoxCopyReferenceCmd);
         ItalicTextItemModel *itim = new ItalicTextItemModel();
         itim->addItem(i18n("No command"), QString());
-        const QStringList citeCommands = QStringList() << QLatin1String("cite") << QLatin1String("citealt") << QLatin1String("citeauthor") << QLatin1String("citeauthor*") << QLatin1String("citeyear") << QLatin1String("citeyearpar") << QLatin1String("shortcite") << QLatin1String("citet") << QLatin1String("citet*") << QLatin1String("citep") << QLatin1String("citep*"); // TODO more
-        foreach (const QString &citeCommand, citeCommands) {
+        const QStringList citeCommands = QStringList() << QStringLiteral("cite") << QStringLiteral("citealt") << QStringLiteral("citeauthor") << QStringLiteral("citeauthor*") << QStringLiteral("citeyear") << QStringLiteral("citeyearpar") << QStringLiteral("shortcite") << QStringLiteral("citet") << QStringLiteral("citet*") << QStringLiteral("citep") << QStringLiteral("citep*"); // TODO more
+        for (const QString &citeCommand : citeCommands) {
             itim->addItem(citeCmdToLabel.arg(citeCommand), citeCommand);
         }
         comboBoxCopyReferenceCmd->setModel(itim);
-        connect(comboBoxCopyReferenceCmd, SIGNAL(currentIndexChanged(int)), p, SIGNAL(changed()));
+        connect(comboBoxCopyReferenceCmd, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), p, &SettingsFileExporterWidget::changed);
 
-        checkboxUseAutomaticLyXPipeDetection = new QCheckBox(QLatin1String(""), p);
+#ifdef QT_LSTAT
+        checkboxUseAutomaticLyXPipeDetection = new QCheckBox(QStringLiteral(""), p);
         layout->addRow(i18n("Detect LyX pipe automatically:"), checkboxUseAutomaticLyXPipeDetection);
-        connect(checkboxUseAutomaticLyXPipeDetection, SIGNAL(toggled(bool)), p, SIGNAL(changed()));
-        connect(checkboxUseAutomaticLyXPipeDetection, SIGNAL(toggled(bool)), p, SLOT(automaticLyXDetectionToggled(bool)));
+        connect(checkboxUseAutomaticLyXPipeDetection, &QCheckBox::toggled, p, &SettingsFileExporterWidget::changed);
+        connect(checkboxUseAutomaticLyXPipeDetection, &QCheckBox::toggled, p, &SettingsFileExporterWidget::automaticLyXDetectionToggled);
+#endif // QT_LSTAT
 
         lineeditLyXPipePath = new KUrlRequester(p);
         layout->addRow(i18n("Manually specified LyX pipe:"), lineeditLyXPipePath);
-        connect(lineeditLyXPipePath->lineEdit(), SIGNAL(textEdited(QString)), p, SIGNAL(changed()));
+        connect(lineeditLyXPipePath->lineEdit(), &KLineEdit::textEdited, p, &SettingsFileExporterWidget::changed);
         lineeditLyXPipePath->setMinimumWidth(lineeditLyXPipePath->fontMetrics().width(QChar('W')) * 20);
-        lineeditLyXPipePath->setFilter(QLatin1String("inode/fifo"));
+        lineeditLyXPipePath->setFilter(QStringLiteral("inode/fifo"));
         lineeditLyXPipePath->setMode(KFile::ExistingOnly | KFile::LocalOnly);
 
         comboBoxBackupScope = new KComboBox(false, p);
@@ -137,21 +155,19 @@ public:
         comboBoxBackupScope->addItem(i18n("Local files only"), Preferences::LocalOnly);
         comboBoxBackupScope->addItem(i18n("Both local and remote files"), Preferences::BothLocalAndRemote);
         layout->addRow(i18n("Backups when saving:"), comboBoxBackupScope);
-        connect(comboBoxBackupScope, SIGNAL(currentIndexChanged(int)), p, SIGNAL(changed()));
+        connect(comboBoxBackupScope, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), p, &SettingsFileExporterWidget::changed);
 
         spinboxNumberOfBackups = new QSpinBox(p);
         spinboxNumberOfBackups->setMinimum(1);
         spinboxNumberOfBackups->setMaximum(16);
         layout->addRow(i18n("Number of Backups:"), spinboxNumberOfBackups);
-        connect(spinboxNumberOfBackups, SIGNAL(valueChanged(int)), p, SIGNAL(changed()));
+        connect(spinboxNumberOfBackups, static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged), p, &SettingsFileExporterWidget::changed);
 
-        connect(comboBoxBackupScope, SIGNAL(currentIndexChanged(int)), p, SLOT(updateGUI()));
+        connect(comboBoxBackupScope, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), p, &SettingsFileExporterWidget::updateGUI);
     }
-
-    // void configGroup(QString arg1, Preferences::BackupScope arg2);
 };
 
-const QString SettingsFileExporterWidget::SettingsFileExporterWidgetPrivate::citeCmdToLabel = QLatin1String("\\%1{") + QChar(0x2026) + QChar('}');
+const QString SettingsFileExporterWidget::SettingsFileExporterWidgetPrivate::citeCmdToLabel = QStringLiteral("\\%1{") + QChar(0x2026) + QChar('}');
 
 SettingsFileExporterWidget::SettingsFileExporterWidget(QWidget *parent)
         : SettingsAbstractWidget(parent), d(new SettingsFileExporterWidgetPrivate(this))
@@ -169,9 +185,9 @@ QString SettingsFileExporterWidget::label() const
     return i18n("Saving and Exporting");
 }
 
-KIcon SettingsFileExporterWidget::icon() const
+QIcon SettingsFileExporterWidget::icon() const
 {
-    return KIcon("document-save");
+    return QIcon::fromTheme(QStringLiteral("document-save"));
 }
 
 void SettingsFileExporterWidget::loadState()
@@ -189,15 +205,17 @@ void SettingsFileExporterWidget::resetToDefaults()
     d->resetToDefaults();
 }
 
+#ifdef QT_LSTAT
 void SettingsFileExporterWidget::automaticLyXDetectionToggled(bool isChecked)
 {
     d->lineeditLyXPipePath->setEnabled(!isChecked);
     if (isChecked) {
-        d->lastUserInput = d->lineeditLyXPipePath->text();
+        d->lastUserInputLyXPipePath = d->lineeditLyXPipePath->text();
         d->lineeditLyXPipePath->setText(LyX::guessLyXPipeLocation());
     } else
-        d->lineeditLyXPipePath->setText(d->lastUserInput);
+        d->lineeditLyXPipePath->setText(d->lastUserInputLyXPipePath);
 }
+#endif // QT_LSTAT
 
 void SettingsFileExporterWidget::updateGUI()
 {
