@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifndef KBIBTEX_PROC_FINDDUPLICATES_H
@@ -27,6 +27,7 @@
 
 class Entry;
 class File;
+class FileModel;
 
 class KBIBTEXPROC_EXPORT FindDuplicates;
 
@@ -77,7 +78,7 @@ class KBIBTEXPROC_EXPORT FindDuplicates : public QObject
 
 public:
     explicit FindDuplicates(QWidget *parent, int sensitivity = 4000);
-    ~FindDuplicates();
+    ~FindDuplicates() override;
 
     bool findDuplicateEntries(File *file, QList<EntryClique *> &entryCliqueList);
 
@@ -85,9 +86,6 @@ signals:
     void maximumProgress(int maxProgress);
     void currentProgress(int progress);
 
-private slots:
-    void gotCanceled();
-
 private:
     class FindDuplicatesPrivate;
     FindDuplicatesPrivate *d;
@@ -99,7 +97,7 @@ private:
 class KBIBTEXPROC_EXPORT MergeDuplicates
 {
 public:
-    static bool mergeDuplicateEntries(const QList<EntryClique *> &entryCliques, File *file);
+    static bool mergeDuplicateEntries(const QList<EntryClique *> &entryCliques, FileModel *fileModel);
 
 private:
     explicit MergeDuplicates();
